@@ -8,19 +8,12 @@ License:LGPL 2.1
  * JammoSlider
  */
 
-//This is because of getline
-#define _GNU_SOURCE
-
-#define VERSION "0.10.22"
-#define PACKAGE "unknown"
-#define GST_PACKAGE_NAME "unknown"
-#define GST_PACKAGE_ORIGIN "unknown" 
-
 #include <math.h>
 #include <stdlib.h>
 #include <string.h>
 #include <gst/controller/gstcontroller.h>
 
+#include "../plugin-common.h"
 #include "gstjammoslider.h"
 
 /*e.g. Nokia Internet Tablet n810 doesn't have this (maemo diablo)*/
@@ -38,9 +31,6 @@ License:LGPL 2.1
 
 #define M_PI_M2 ( M_PI + M_PI )
 
-GST_DEBUG_CATEGORY_STATIC (jammo_slider_debug);
-#define GST_CAT_DEFAULT jammo_slider_debug
-
 static const GstElementDetails gst_jammo_slider_details =
 GST_ELEMENT_DETAILS ("JamMo Slider",
     "Source/Audio",
@@ -133,8 +123,7 @@ static GstFlowReturn gst_jammo_slider_create (GstBaseSrc * basesrc,
     guint64 offset, guint length, GstBuffer ** buffer);
 
 
-static void
-gst_jammo_slider_base_init (gpointer g_class)
+static void gst_jammo_slider_base_init (gpointer g_class)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
 
@@ -144,11 +133,6 @@ gst_jammo_slider_base_init (gpointer g_class)
 }
 
 
-static gfloat interpolation(gfloat interpolation_point, gfloat value1, gfloat value2) {
-        /* linear interpolation */
-        return ((1-interpolation_point)*value1 + interpolation_point*value2);
-}
-
 
 /*
 Some day we will have three different instrument using slider.
@@ -199,15 +183,14 @@ gfloat karplus(GstJammoSlider * src){
 return (gfloat) karplus_strong(inp, src->samplerate/freq)/32767;
 }
 
-static InstrumentFunc instruments[] = {
-  (InstrumentFunc) organ,
-  (InstrumentFunc) fm_modulation,
-  (InstrumentFunc) karplus
+static JammoSliderInstrumentFunc instruments[] = {
+  (JammoSliderInstrumentFunc) organ,
+  (JammoSliderInstrumentFunc) fm_modulation,
+  (JammoSliderInstrumentFunc) karplus
 };
 
 
-static void
-gst_jammo_slider_class_init (GstJammoSliderClass * klass)
+static void gst_jammo_slider_class_init (GstJammoSliderClass * klass)
 {
   GObjectClass *gobject_class;
   GstBaseSrcClass *gstbasesrc_class;
@@ -292,8 +275,7 @@ gst_jammo_slider_class_init (GstJammoSliderClass * klass)
   gstbasesrc_class->create = GST_DEBUG_FUNCPTR (gst_jammo_slider_create);
 }
 
-static void
-gst_jammo_slider_init (GstJammoSlider * src, GstJammoSliderClass * g_class)
+static void gst_jammo_slider_init (GstJammoSlider * src, GstJammoSliderClass * g_class)
 {
   GstPad *pad = GST_BASE_SRC_PAD (src);
 
@@ -326,8 +308,7 @@ gst_jammo_slider_init (GstJammoSlider * src, GstJammoSliderClass * g_class)
 
 }
 
-static void
-gst_jammo_slider_src_fixate (GstPad * pad, GstCaps * caps)
+static void gst_jammo_slider_src_fixate (GstPad * pad, GstCaps * caps)
 {
   GstJammoSlider *src = GST_JAMMO_SLIDER (GST_PAD_PARENT (pad));
   const gchar *name;
@@ -346,10 +327,9 @@ gst_jammo_slider_src_fixate (GstPad * pad, GstCaps * caps)
     gst_structure_fixate_field_nearest_int (structure, "width", 64);
 }
 
-static ProcessFunc process_funcs[];
+static JammoSliderProcessFunc process_funcs[];
 
-static gboolean
-gst_jammo_slider_setcaps (GstBaseSrc * basesrc, GstCaps * caps)
+static gboolean gst_jammo_slider_setcaps (GstBaseSrc * basesrc, GstCaps * caps)
 {
   GstJammoSlider *src = GST_JAMMO_SLIDER (basesrc);
   const GstStructure *structure;
@@ -406,8 +386,7 @@ gst_jammo_slider_setcaps (GstBaseSrc * basesrc, GstCaps * caps)
   return ret;
 }
 
-static gboolean
-gst_jammo_slider_query (GstBaseSrc * basesrc, GstQuery * query)
+static gboolean gst_jammo_slider_query (GstBaseSrc * basesrc, GstQuery * query)
 {
   GstJammoSlider *src = GST_JAMMO_SLIDER (basesrc);
   gboolean res = FALSE;
@@ -501,44 +480,6 @@ static gfloat freq_rounding(gfloat slider_freq){
 }
 
 
-gfloat pitch(gint needed_pitch){
-	gfloat pitch=1.0;
-		if (needed_pitch<=0)
-			while (needed_pitch<0) {
-				pitch*=0.9439;
-				needed_pitch++;
-			}
-
-		else
-			while (needed_pitch>0) {
-				pitch*=1.0595;
-				needed_pitch--;
-			}
-		
-	return pitch;
-}
-
-gfloat xfader(gint16 *sampletable, gfloat *xfadecounter, gfloat *xfadeindex, gint xfade, gfloat value, gfloat scale, gint needed_pitch, gint samplerate) {
-
-	gfloat xfademix;
-
-	/* linear crossfade */
-	/* fade in signal */
-	xfademix= (0.0+1.0* (*xfadecounter)/(xfade*1.0));
-	value*= xfademix;
-	/* fade out signal */
-	xfademix= (1.0-1.0* (*xfadecounter)/(xfade*1.0));
-	value+= (xfademix)*( interpolation( *xfadeindex-(gint)*xfadeindex, sampletable[(gint)*xfadeindex], sampletable[((gint)*xfadeindex+1)] ) /(G_MAXINT16*1.0) * scale);
-	/* Compensation of volume loss during crossfade */
-	/*values[counter]*=1.05-fabs(0.05-0.1* (*xfadecounter)/(*xfade*1.0));*/
-	*xfadecounter+=1.0;
-	/* 44100 is samplerate of sample files. value could be read from wav header and stored to i.e slicedWav->samplerate. then we would be able to used samples with different sample rates */
-	/* samplerate variable has the output samplerate of jammoslider */
-	*xfadeindex += pitch(needed_pitch)*44100/(samplerate+0.0);
-
-	return value;
-}
-
 #define DEFINE_PROCESS(type,scale) \
 static void gst_jammo_slider_process_##type (GstJammoSlider * src, g##type * samples) {\
 	/* if volume is divided with number of playing tones instrument*/\
@@ -648,16 +589,15 @@ DEFINE_PROCESS (float, 1.0);
 DEFINE_PROCESS (double, 1.0);
 
 
-static ProcessFunc process_funcs[] = {
-  (ProcessFunc) gst_jammo_slider_process_int16,
-  (ProcessFunc) gst_jammo_slider_process_int32,
-  (ProcessFunc) gst_jammo_slider_process_float,
-  (ProcessFunc) gst_jammo_slider_process_double
+static JammoSliderProcessFunc process_funcs[] = {
+  (JammoSliderProcessFunc) gst_jammo_slider_process_int16,
+  (JammoSliderProcessFunc) gst_jammo_slider_process_int32,
+  (JammoSliderProcessFunc) gst_jammo_slider_process_float,
+  (JammoSliderProcessFunc) gst_jammo_slider_process_double
 };
 
 
-static void
-gst_jammo_slider_get_times (GstBaseSrc * basesrc, GstBuffer * buffer,
+static void gst_jammo_slider_get_times (GstBaseSrc * basesrc, GstBuffer * buffer,
     GstClockTime * start, GstClockTime * end)
 {
   /* for live sources, sync on the timestamp of the buffer */
@@ -679,8 +619,7 @@ gst_jammo_slider_get_times (GstBaseSrc * basesrc, GstBuffer * buffer,
   }
 }
 
-static gboolean
-gst_jammo_slider_start (GstBaseSrc * basesrc)
+static gboolean gst_jammo_slider_start (GstBaseSrc * basesrc)
 {
   GstJammoSlider *src = GST_JAMMO_SLIDER (basesrc);
   int i;
@@ -699,16 +638,14 @@ gst_jammo_slider_start (GstBaseSrc * basesrc)
   return TRUE;
 }
 
-static gboolean
-gst_jammo_slider_stop (GstBaseSrc * basesrc)
+static gboolean gst_jammo_slider_stop (GstBaseSrc * basesrc)
 {
   return TRUE;
 }
 
 /* seek to time, will be called when we operate in push mode. In pull mode we
  * get the requiested byte offset. */
-static gboolean
-gst_jammo_slider_do_seek (GstBaseSrc * basesrc, GstSegment * segment)
+static gboolean gst_jammo_slider_do_seek (GstBaseSrc * basesrc, GstSegment * segment)
 {
   GstJammoSlider *src = GST_JAMMO_SLIDER (basesrc);
   GstClockTime time;
@@ -738,15 +675,13 @@ gst_jammo_slider_do_seek (GstBaseSrc * basesrc, GstSegment * segment)
   return TRUE;
 }
 
-static gboolean
-gst_jammo_slider_is_seekable (GstBaseSrc * basesrc)
+static gboolean gst_jammo_slider_is_seekable (GstBaseSrc * basesrc)
 {
   /* we're seekable... */
   return TRUE;
 }
 
-static gboolean
-gst_jammo_slider_check_get_range (GstBaseSrc * basesrc)
+static gboolean gst_jammo_slider_check_get_range (GstBaseSrc * basesrc)
 {
   GstJammoSlider *src;
 
@@ -756,9 +691,8 @@ gst_jammo_slider_check_get_range (GstBaseSrc * basesrc)
   return src->can_activate_pull;
 }
 
-static GstFlowReturn
-gst_jammo_slider_create (GstBaseSrc * basesrc, guint64 offset,
-    guint length, GstBuffer ** buffer)
+static GstFlowReturn gst_jammo_slider_create (GstBaseSrc * basesrc, 
+    guint64 offset, guint length, GstBuffer ** buffer)
 {
   GstFlowReturn res;
   GstJammoSlider *src;
@@ -865,8 +799,7 @@ gst_jammo_slider_create (GstBaseSrc * basesrc, guint64 offset,
   return GST_FLOW_OK;
 }
 
-static void
-gst_jammo_slider_set_property (GObject * object, guint prop_id,
+static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec)
 {
   GstJammoSlider *src = GST_JAMMO_SLIDER (object);
@@ -932,8 +865,7 @@ gst_jammo_slider_set_property (GObject * object, guint prop_id,
   }
 }
 
-static void
-gst_jammo_slider_get_property (GObject * object, guint prop_id,
+static void gst_jammo_slider_get_property (GObject * object, guint prop_id,
     GValue * value, GParamSpec * pspec)
 {
   GstJammoSlider *src = GST_JAMMO_SLIDER (object);
@@ -984,22 +916,3 @@ gst_jammo_slider_get_property (GObject * object, guint prop_id,
 
   }
 }
-
-static gboolean
-plugin_init (GstPlugin * plugin)
-{
-
-  /* initialize gst controller library */
-  gst_controller_init (NULL, NULL);
-
-  GST_DEBUG_CATEGORY_INIT (jammo_slider_debug, "jammoslider", 0,
-      "Jammo Slider Instrument");
-  return gst_element_register (plugin, "jammoslider",
-      GST_RANK_NONE, GST_TYPE_JAMMO_SLIDER);
-}
-
-GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
-    GST_VERSION_MINOR,
-    "jammoslider",
-    "Creates slider instrument",
-    plugin_init, VERSION, "LGPL", GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN);
